OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor esbilla un ficheru.",
    "File is too big" : "Ficheru ye demasiáu grande",
    "Invalid file provided" : "el ficheru apurríu nun ye válidu",
    "No image or file provided" : "Nun s'especificó nenguna imaxe o ficheru",
    "Unknown filetype" : "Triba de ficheru desconocida",
    "Invalid image" : "Imaxe inválida",
    "An error occurred. Please contact your admin." : "Hebo un fallu. Por favor, contauta col to alministrador",
    "No temporary profile picture available, try again" : "Nengún perfil d'imaxe temporal disponible, intentalo de nueves",
    "No crop data provided" : "Nun s'apurrió'l retayu de datos",
    "No valid crop data provided" : "El retayu de datos apurríu nun ye válidu",
    "Crop is not square" : "El retayu nun ye cuadráu",
    "Couldn't reset password because the token is invalid" : "Nun pudo reaniciase la contraseña porque'l token ye inválidu",
    "Couldn't reset password because the token is expired" : "Nun pudo reaniciase la contraseña porque'l token ye inválidu",
    "%s password reset" : "%s restablecer contraseña",
    "Couldn't send reset email. Please contact your administrator." : "Nun pudo unviase'l corréu de reaniciu. Por favor, contauta col alministrador.",
    "Couldn't send mail to following users: %s " : "Nun pudo unviase'l corréu a los usuarios siguientes: %s",
    "Preparing update" : "Preparando anovamientu",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Reparar avisu:",
    "Repair error: " : "Reparar erru:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor, usa l'actualización de llínea de comandos porque l'actualización automática ta deshabilitada nel config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Comprobando tabla %s",
    "Turned on maintenance mode" : "Activáu'l mou de caltenimientu",
    "Turned off maintenance mode" : "Apagáu'l mou de caltenimientu",
    "Maintenance mode is kept active" : "La mou de caltenimientu caltiense activu",
    "Updating database schema" : "Anovando esquema de base de datos",
    "Updated database" : "Base de datos anovada",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Comprobando si l'esquema de base de datos puede ser actualizáu (esto puede llevar tiempu abondo, dependiendo del tamañu la base de datos)",
    "Checked database schema update" : "Anovamientu del esquema de base de datos revisáu",
    "Checking updates of apps" : "Comprobando anovamientos d'aplicaciones",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Comprobando si l'esquema de base de datos para %s puede ser actualizáu (esto puede llevar tiempu abondo, dependiendo del tamañu la base de datos)",
    "Checked database schema update for apps" : "Anovamientu del esquema de base de datos p'aplicaciones revisáu",
    "Updated \"%s\" to %s" : "Anováu \"%s\" a %s",
    "Set log level to debug" : "Afita'l nivel de rexistru pa depurar",
    "Reset log level" : "Reafitar nivel de rexistru",
    "Starting code integrity check" : "Entamando la comprobación de la integridá del códigu",
    "Finished code integrity check" : "Finada la comprobación de la integridá del códigu",
    "%s (3rdparty)" : "%s (3rdparty)",
    "%s (incompatible)" : "%s (incompatible)",
    "Following apps have been disabled: %s" : "Siguientes aplicaciones deshabilitáronse: %s",
    "Already up to date" : "Yá ta actualizáu",
    "Sunday" : "Domingu",
    "Monday" : "Llunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Xueves",
    "Friday" : "Vienres",
    "Saturday" : "Sábadu",
    "Sun." : "Dom.",
    "Mon." : "Llu.",
    "Tue." : "Mar.",
    "Wed." : "Mié.",
    "Thu." : "Xue.",
    "Fri." : "Vie.",
    "Sat." : "Sáb.",
    "Su" : "Do",
    "Mo" : "Llu",
    "Tu" : "Ma",
    "We" : "Mie",
    "Th" : "Xue",
    "Fr" : "Vie",
    "Sa" : "Sa",
    "January" : "Xineru",
    "February" : "Febreru",
    "March" : "Marzu",
    "April" : "Abril",
    "May" : "Mayu",
    "June" : "Xunu",
    "July" : "Xunetu",
    "August" : "Agostu",
    "September" : "Setiembre",
    "October" : "Ochobre",
    "November" : "Payares",
    "December" : "Avientu",
    "Jan." : "Xin.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Xun.",
    "Jul." : "Xnt.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Och.",
    "Nov." : "Pay.",
    "Dec." : "Avi.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Hebo un problema cola comprobación de la integridá del códigu. Más información...</a>",
    "Settings" : "Axustes",
    "Problem loading page, reloading in 5 seconds" : "Problema al cargar la páxina, volver cargar en 5 segundos",
    "Saving..." : "Guardando...",
    "Dismiss" : "Encaboxar",
    "seconds ago" : "hai segundos",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Unviósete al corréu l'enllaz pa reaniciar la to contraseña. Si nun lu recibes nuna cantidá razonable de tiempu, comprueba les tos carpetes de corréu puxarra. <br>Si nun ta ehí, entruga al to alministrador llocal",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Los tos ficheros tán crifraos. Si nun habilitesti la clave de recuperación, nun habrá forma de recuperar los tos datos dempués de que se reanicie la to contraseña.<br />Si nun tas seguru de qué facer, por favor contauta col to alministrador enantes que sigas. <br />¿De xuru quies siguir?",
    "I know what I'm doing" : "Sé lo que toi faciendo",
    "Password can not be changed. Please contact your administrator." : "Nun pue camudase la contraseña. Por favor, contauta col alministrador.",
    "No" : "Non",
    "Yes" : "Sí",
    "Choose" : "Esbillar",
    "Error loading file picker template: {error}" : "Fallu cargando'l ficheru de plantía d'escoyeta: {error}",
    "Ok" : "Aceutar",
    "Error loading message template: {error}" : "Fallu cargando'l mensaxe de la plantía: {error}",
    "read-only" : "namái llectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflictu de ficheru","{count} conflictos de ficheru "],
    "One file conflict" : "Conflictu nun ficheru",
    "New Files" : "Ficheros nuevos",
    "Already existing files" : "Ficheros qu'esisten yá",
    "Which files do you want to keep?" : "¿Qué ficheros quies caltener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleiciones dambes versiones, el ficheru copiáu va tener un númberu amestáu al so nome",
    "Cancel" : "Encaboxar",
    "Continue" : "Continuar",
    "(all selected)" : "(esbillao too)",
    "({count} selected)" : "(esbillaos {count})",
    "Error loading file exists template" : "Falu cargando plantía de ficheru esistente",
    "Very weak password" : "Contraseña mui feble",
    "Weak password" : "Contraseña feble",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña bona",
    "Strong password" : "Contraseña mui bona",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "El to sirvidor web entá nun ta configuráu afayadizamente pa permitir la sincronización de ficheros porque la interfaz WebDAV paez tar rota.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "El to sirvidor web nun ta configuráu correchamente pa resolver  \"{url}\". Pues atopar más información en nuesa documentación <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\"></a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Esti sirvidor nun tien conexón a Internet. Esto significa que dalgunes de les carauterístiques nun van funcionar, como'l montaxe d'almacenamiento esternu, les notificaciones sobre anovamientos, la instalación d'aplicaciones de terceros, l'accesu a los ficheros de mou remotu o l'unviu de correos-e de notificación. Suxerimos habilitar una conexón a Internet nesti sirvidor pa esfrutar de toles funciones.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Configuróse ensin la memoria caché. P'ameyorar el so rendimientu configure un Memcache si ta disponible. Puede atopar más información na nuesa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentación</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom nun ye llexible por PHP que amás nun ye recomendable por razones de seguridá. Pues atopar más información na nuesa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentación</a>.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Ta executándose anguaño la {version} PHP. Convidamoste a actualizar la to versión PHP p'aprovechate del <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\"> rendimientu y actualizaciones de seguridá proporcionaes pol Grupu PHP</a> desque la so distribución sofitelo.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "La configuración de les cabeceres de proxy inverses ye incorrecta , o tas aportando ownCloud dende un proxy d'enfotu . Si nun tas aportando a ownCloud dende un proxy d'enfotu, esto ye un problema de seguridá y puede dexar a un atacante falsificar la so dirección IP como visible pa ownCloud . Más información puede atopase na nuesa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentación</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached configúrase como caché distribuyida, pero instalóse'l módulu de PHP \"Memcache\" equivocáu.  \\OC\\Memcache\\Memcached namás almite \"memcached\"  y non  \"memcache\". Vea la <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\"> wiki memcached sobre ambos módulos</a> .",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Dellos arquivos nun pasaron la comprobación d'integridá. Pues atopas más información sobre cómo resolver esti problema na nuesa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\"> Llista de ficheros non válidos...</a>/ <a href=\"{rescanEndpoint}\">Volver a guetar…</a>)",
    "Error occurred while checking server setup" : "Asocedió un fallu mientres se comprobaba la configuración del sirvidor",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "El direutoriu de datos y ficheros ye dablemente accesible dende Internet, darréu que'l ficheru .htaccess nun ta funcionando. Suxerímoste que configures el sirvidor web de mou que'l direutoriu de datos nun seya accesible o que muevas talu direutoriu fuera del raigañu de documentos del sirvidor web.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "La \"{header}\" HTTP nun ta configurada pa igualar a \"{expected}\". Esto ye una seguridá o privacidá potencial de riesgu y encamentamos axustar esta opción.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "La cabecera HTTP \"Estrictu-Tresporte-Seguridá\" nun ta configurada pa siquier \"{seconds}\"  segundos. Pa mayor seguridá encamentámos-y habilitar HSTS como se describe en nuesos <a href=\"{docUrl}\" rel=\"noreferrer\">conseyos de seguridá</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Tas ingresando a esti sitiu vía HTTP. Encamentámoste que configures el sirvidor pa solicitar HTTPS como describimos en nuesos  <a href=\"{docUrl}\">conseyos de seguridá</a>.",
    "Shared" : "Compartíu",
    "Shared with {recipients}" : "Compartío con {recipients}",
    "Error" : "Fallu",
    "Error while sharing" : "Fallu mientres la compartición",
    "Error while unsharing" : "Fallu mientres se dexaba de compartir",
    "The public link will expire no later than {days} days after it is created" : "L'enllaz públicu va caducar enantes de {days} díes dende la so creación",
    "Set expiration date" : "Afitar la data de caducidá",
    "Expiration" : "Caducidá",
    "Expiration date" : "Data de caducidá",
    "Link" : "Enllaz",
    "Edit" : "Editar",
    "Remove" : "Desaniciar",
    "Copied!" : "¡Copiáu!",
    "Not supported!" : "¡Non soportáu!",
    "Press ⌘-C to copy." : "Calca ⌘-C pa copiar",
    "Press Ctrl-C to copy." : "Calca  Ctrl-C pa copiar.",
    "Choose a password for the public link" : "Escueyi una contraseña pal enllaz públicu",
    "Filename" : "Nome de Ficheru",
    "Password" : "Contraseña",
    "Name" : "Nome",
    "Allow editing" : "Permitir edición",
    "Save" : "Guardar",
    "Error while sending notification" : "Fallu mientres s'unviaba la notificación",
    "Sending ..." : "Unviando ...",
    "Email sent" : "Corréu unviáu",
    "Email link to person" : "Enllaz de corréu-e a la persona",
    "Send link via email" : "Unviáu enllaz por email",
    "Shared with you and the group {group} by {owner}" : "Compartíu contigo y col grupu {group} por {owner}",
    "Shared with you by {owner}" : "Compartíu contigo por {owner}",
    "group" : "grupu",
    "remote" : "remotu",
    "notify by email" : "notificar per corréu",
    "Unshare" : "Dexar de compartir",
    "can share" : "pue compartir",
    "can edit" : "pue editar",
    "create" : "crear",
    "change" : "camudar",
    "delete" : "desaniciar",
    "access control" : "control d'accesu",
    "Could not unshare" : "Nun pudo dexase de compartir",
    "Share details could not be loaded for this item." : "Los detalles de les acciones nun pudieron cargase por esti elementu.",
    "No users or groups found for {search}" : "Nun s'atopó nengún usuariu o grupu por {search}",
    "No users found for {search}" : "Nun s'atoparon usuarios por {search}",
    "An error occurred. Please try again" : "Hebo un fallu. Por favor, inténtalo de nueves",
    "{sharee} (group)" : "{sharee} (grupu)",
    "{sharee} (at {server})" : "{sharee} (en {server})",
    "{sharee} (remote)" : "{sharee} (remotu)",
    "Share" : "Compartir",
    "Resharing is not allowed" : "Recompartir nun ta permitíu",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartir con xente d'otros ownClouds usando la sintaxis usuariu@exemplu.com/owncloud",
    "Share with users…" : "Compartir con usuarios...",
    "Share with users, groups or remote users…" : "Compartir con usuarios, grupos o usuarios remotos...",
    "Share with users or groups…" : "Compartir con usuarios o grupos...",
    "Share with users or remote users…" : "Compartir con usuarios o usuarios remotos...",
    "Error removing share" : "Fallu desaniciando compartición",
    "Warning" : "Avisu",
    "Non-existing tag #{tag}" : "Nun esiste la etiqueta #{tag}",
    "restricted" : "torgáu",
    "invisible" : "invisible",
    "({scope})" : "({scope})",
    "Delete" : "Desaniciar",
    "Rename" : "Renomar",
    "Collaborative tags" : "Etiquetes colaboratives",
    "The object type is not specified." : "El tipu d'oxetu nun ta especificáu.",
    "Enter new" : "Introducir nueva",
    "Add" : "Amestar",
    "Edit tags" : "Editar etiquetes",
    "Error loading dialog template: {error}" : "Fallu cargando plantía de diálogu: {error}",
    "No tags selected for deletion." : "Nun s'esbillaron etiquetes pa desaniciar.",
    "unknown text" : "testu desconocíu",
    "Hello world!" : "¡Hola mundiu!",
    "sunny" : "soleyeru",
    "Hello {name}, the weather is {weather}" : "Hola {name}, el tiempu ta {weather}",
    "Hello {name}" : "Hola {name}",
    "new" : "nuevu",
    "_download %n file_::_download %n files_" : ["descargando %n ficheru","descargando %n ficheros"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "L'actualización ta en cursu, salir d'esta páxina podría atayar el procesu en dellos entornos.",
    "Updating to {version}" : "Anovando a {version}",
    "An error occurred." : "Hebo un fallu",
    "Please reload the page." : "Por favor, recarga la páxina",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "L'actualización nun tuvo ésitu . Pa más información  <a href=\"{url}\">comprueba'l nuesu post del foro</a> falando d'esti tema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "L'anovamientu fízose con ésitu. Por favor, informa d'esti problema a la <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">comuña ownCloud</a>.",
    "The update was successful. There were warnings." : "L'anovamientu fízose con ésitu. Hai dellos avisos.",
    "The update was successful. Redirecting you to ownCloud now." : "L'anovamientu fízose con ésitu. Redirixiendo agora al to ownCloud.",
    "Searching other places" : "Guetando otros llugares",
    "No search results in other folders" : "Nengún resultáu en otros direutorios",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["Atopose {count} resultáu en otros direutorios","Atopáronse {count} resultaos en otros direutorios"],
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Alministrador",
    "Help" : "Ayuda",
    "Access forbidden" : "Accesu denegáu",
    "File not found" : "Nun s'atopó el ficheru",
    "The specified document has not been found on the server." : "El documentu especificáu nun s'atopó nel servidor.",
    "You can click here to return to %s." : "Pues calcar equí pa volver a %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hola, ¿qué hai?\n\nnamái déxanos dicite que %s compartió %s contigo.\nVelu: %s\n\n",
    "The share will expire on %s." : "La compartición va caducar el %s.",
    "Cheers!" : "¡Salú!",
    "Internal Server Error" : "Fallu de Sirvidor Internu",
    "The server encountered an internal error and was unable to complete your request." : "El sirvidor atopó un erru internu y nun pudo completar la so solicitú.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Por favor, póngase en contactu col alministrador del sirvidor si esti erru vuelve apaecer delles vegaes, por favor incluya los detalles técnicos nel so informe.",
    "More details can be found in the server log." : "Puede atopar más detalles nel rexistru del servidor. ",
    "Technical details" : "Detalles teúnicos",
    "Remote Address: %s" : "Accesu Remotu: %s",
    "Request ID: %s" : "Solicitú d'ID: %s",
    "Type: %s" : "Triba: %s",
    "Code: %s" : "Códigu: %s",
    "Message: %s" : "Mensaxe: %s",
    "File: %s" : "Ficheru: %s",
    "Line: %s" : "Llínea: %s",
    "Trace" : "Traza",
    "Create an <strong>admin account</strong>" : "Crea una <strong>cuenta d'alministrador</strong>",
    "Username" : "Nome d'usuariu",
    "Storage & database" : "Almacenamientu y Base de datos",
    "Data folder" : "Carpeta de datos",
    "Configure the database" : "Configura la base de datos",
    "Only %s is available." : "Namái ta disponible %s",
    "Install and activate additional PHP modules to choose other database types." : "Instalar y activar los módulos de PHP adicionales pa escoyer otra triba de bases de datos.",
    "For more details check out the documentation." : "Pa más detalles comprueba la documentación.",
    "Database user" : "Usuariu de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nome de la base de datos",
    "Database tablespace" : "Espaciu de tables de la base de datos",
    "Database host" : "Agospiador de la base de datos",
    "Performance warning" : "Avisu de rendimientu",
    "SQLite will be used as database." : "SQLite va utilizase como base de datos.",
    "For larger installations we recommend to choose a different database backend." : "Pa instalaciones más grandes encamiéntase escoyer un motor de base de datos distintu.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especialmente cuando s'utiliza'l veceru d'escritoriu pa la sincronización de ficheros l'usu de SQLite ta desaconseyáu .",
    "Finish setup" : "Finar la configuración ",
    "Finishing …" : "Finando ...",
    "Need help?" : "¿Precises sofitu?",
    "See the documentation" : "Consulta la documentación",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hola, ¿qué hai?,<br><br>namái déxamos dicite que %s compartió <strong>%s</strong> contigo.\n<br><a href=\"%s\">¡Velu!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación rique JavaScript pal so correctu funcionamientu. Por favor {linkstart}habilitaJavaScript{linkend} y recarga la páxina.",
    "Log out" : "Zarrar sesión",
    "Search" : "Guetar",
    "Server side authentication failed!" : "Falló l'autenticación nel sirvidor!",
    "Please contact your administrator." : "Por favor, contauta col to alministrador",
    "An internal error occurred." : "Hebo un fallu internu.",
    "Please try again or contact your administrator." : "Por favor, inténtalo de nueves o ponte en contactu col alministrador.",
    "Username or email" : "Nome d'usuariu o email",
    "Log in" : "Aniciar sesión",
    "Wrong password. Reset it?" : "Contraseña incorreuta. ¿Reafitala?",
    "Wrong password." : "Contraseña incorreuta.",
    "Stay logged in" : "Permanecer conectáu",
    "Alternative Logins" : "Anicios de sesión alternativos",
    "Use the following link to reset your password: {link}" : "Usa'l siguiente enllaz pa restablecer la to contraseña: {link}",
    "New password" : "Contraseña nueva",
    "New Password" : "Contraseña nueva",
    "Reset password" : "Restablecer contraseña",
    "This ownCloud instance is currently in single user mode." : "Esta instalación d'ownCloud ta en mou d'usuariu únicu.",
    "This means only administrators can use the instance." : "Esto quier dicir que namái pue usala un alministrador.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contauta col alministrador si esti problema sigui apaeciendo.",
    "Thank you for your patience." : "Gracies pola to paciencia.",
    "Two-step verification" : "Verificación de dos pasos",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Habilitóse pa la so cuenta la seguridá ameyorada. Por favor autentica por aciu d'un segundu factor.",
    "Cancel login" : "Encaboxar aniciu de sesión",
    "Please authenticate using the selected factor." : "Por favor autentificate usando'l factor escoyíu.",
    "You are accessing the server from an untrusted domain." : "Tas accediendo al sirvidor dende un dominiu non confiáu.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Por favor, contauta col alministrador. Si yes l'alministrador d'esta instancia, configura l'axuste \"trusted_domain\" en config/config.php. Hai un exemplu en config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Dependiendo la so configuración , como administrador también puedes utilizar el botón d'abaxu p'afitar esti dominiu.",
    "Add \"%s\" as trusted domain" : "Amestáu \"%s\" como dominiu de confianza",
    "App update required" : "Actualización de l'aplicación riquida",
    "%s will be updated to version %s" : "%s anovaráse a la versión %s",
    "These apps will be updated:" : "Estes aplicaciones van anovase:",
    "The theme %s has been disabled." : "Deshabilitóse'l tema %s.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enantes de siguir, asegúrate de que se fizo una copia de seguridá de la base de datos, la carpeta de configuración y la carpeta de datos.",
    "Start update" : "Aniciar anovamientu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pa evitar tiempos d'espera con instalaciones más grandes, nel so llugar puede executar el siguiente comandu dende'l directoriu d'instalación:",
    "Detailed logs" : "Rexistros detallaos",
    "Update needed" : "Anovamientu necesariu",
    "Please use the command line updater because you have a big instance." : "Por favor, usa l'actualización de llínea de comandos porque ties una instancia grande.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Pa llograr sofitu, consulte la  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentación</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s  ta anguaño en mou de mantenimientu, polo que pue tardar un pocoñín.",
    "This page will refresh itself when the %s instance is available again." : "Esta páxina va anovase sola cuando la instancia %s tea disponible de nueves.",
    "Copy to clipboard" : "Copiar al cartafueyu",
    "Menu" : "Menú",
    "Imprint" : "Imprint"
},
"nplurals=2; plural=(n != 1);");
